[FIX] mail: batch insert of fetched channel members

This reduces the time of the method from 400ms to 40ms on my machine.

closes odoo/odoo#147814

Signed-off-by: Alexandre Kühn (aku) <aku@odoo.com>
This commit is contained in:
Sébastien Theys
2024-01-03 16:59:13 +00:00
parent f9bd7d4c6c
commit 44dcc1a35f
@@ -87,11 +87,13 @@ export class ThreadService {
channelMembers = results["channelMembers"][0][1];
}
thread.memberCount = results["memberCount"];
for (const channelMember of channelMembers) {
if (channelMember.persona || channelMember.partner) {
thread.channelMembers.add({ ...channelMember, thread });
Record.MAKE_UPDATE(() => {
for (const channelMember of channelMembers) {
if (channelMember.persona || channelMember.partner) {
thread.channelMembers.add({ ...channelMember, thread });
}
}
}
});
}
/**